/* NodeRegistrar.java -- Maintains a register of created nodes.
 Copyright (C) 2005  The University of Sheffield.

 This file is part of the CASheW-s editor Eclipse plug-in.

 The CASheW-s editor Eclipse plug-in is free software; you may copy, modify,
 and redistribute it under the terms of the GNU General Public License
 version 2 (or, at your option, any later version), and/or the Eclipse
 Public License version 1.0.
 
 The CASheW-s editor is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with The CASheW-s editor; see the file COPYING.  If not, write to the
 Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 02111-1307 USA.

 The University of Sheffield makes available all content in this plug-in
 ("Content"). Unless otherwise indicated below, the Content is provided to
 you under the terms and conditions of the Eclipse Public License Version
 1.0 ("EPL"). A copy of the EPL is available at
 http://www.eclipse.org/legal/epl-v10.html. For purposes of the EPL,
 "Program" will mean the Content.

 If you did not receive this Content directly from the University of Sheffield,
 the Content is being redistributed by another party ("Redistributor") and
 different terms and conditions may apply to your use of any object code in
 the Content. Check the Redistributor's license that was provided with the
 Content. If no such license exists, contact the Redistributor. Unless
 otherwise indicated below, the terms and conditions of the EPL still apply
 to any source code in the Content.

 */


package nongnu.cashews.eclipse.composer.model;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;



/**
 * @author Andrew John Hughes (gnu_andrew@member.fsf.org)
 * @author Xianfeng Liu (acp04xfl@shef.ac.uk)
 */

public class NodeRegistrar
{

  private static Set<String> names;

  private static List<String> temps;

  static
    {
      names = new HashSet<String>();
      temps = new ArrayList<String>();
    }

  public static boolean registerNewNode(String name, Diagram d)
  {
    if(d.nodes == null)
    {
     return true;   
    }
    Iterator i = d.nodes.iterator();
    names.clear();
    while(i.hasNext())
    {
      names.add(((Node)i.next()).getName());
    }
    
    if (names.contains(name))
    {
        return false;
    }
    return true;
  }

  public int getMax(Diagram d)
  {
    int m=0;
    int temp=0;
    Iterator i = d.nodes.iterator();
    names.clear();
    while(i.hasNext())
    {
        temp = (Integer.parseInt(((Node)i.next()).getName().substring(8)));
        if (m < temp)
        {
            m = temp;
        }
    }
   return m;

  }

  public static boolean renameNode(String oldName, String newName, Diagram d)
  {
    if (registerNewNode(newName, d))
      {
        removeNode(oldName);
        return true;
      }
    else
      return false;
  }

  public static void removeNode(String name)
  {
    names.remove(name);
    
  }

}
