/* DirectEditPolicy.java -- Direct editing policy.
   Copyright (C) 2005  The University of Sheffield.

This file is part of the CASheW-s editor Eclipse plug-in.

The CASheW-s editor Eclipse plug-in is free software; you may copy, modify,
and redistribute it under the terms of the GNU General Public License
version 2 (or, at your option, any later version), and/or the Eclipse
Public License version 1.0.
 
The CASheW-s editor is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with The CASheW-s editor; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

The University of Sheffield makes available all content in this plug-in
("Content"). Unless otherwise indicated below, the Content is provided to
you under the terms and conditions of the Eclipse Public License Version
1.0 ("EPL"). A copy of the EPL is available at
http://www.eclipse.org/legal/epl-v10.html. For purposes of the EPL,
"Program" will mean the Content.

If you did not receive this Content directly from the University of Sheffield,
the Content is being redistributed by another party ("Redistributor") and
different terms and conditions may apply to your use of any object code in
the Content. Check the Redistributor's license that was provided with the
Content. If no such license exists, contact the Redistributor. Unless
otherwise indicated below, the terms and conditions of the EPL still apply
to any source code in the Content.

*/

package nongnu.cashews.eclipse.composer.policies;

import nongnu.cashews.eclipse.composer.commands.RenameNodeCommand;
import nongnu.cashews.eclipse.composer.figures.PerformanceNodeFigure;
import nongnu.cashews.eclipse.composer.figures.EndPointFigure;
import nongnu.cashews.eclipse.composer.figures.RectangleNodeFigure;
import nongnu.cashews.eclipse.composer.figures.StartPointFigure;
import nongnu.cashews.eclipse.composer.model.Diagram;
import nongnu.cashews.eclipse.composer.model.PerformanceElement;
import nongnu.cashews.eclipse.composer.model.EndPointNode;
import nongnu.cashews.eclipse.composer.model.Node;
import nongnu.cashews.eclipse.composer.model.RectangleNode;
import nongnu.cashews.eclipse.composer.model.StartPointNode;

import org.eclipse.gef.commands.Command;
import org.eclipse.gef.editpolicies.DirectEditPolicy;
import org.eclipse.gef.requests.DirectEditRequest;

public class NodeDirectEditPolicy 
  extends DirectEditPolicy
{

  // ------------------------------------------------------------------------
  // Abstract methods from DirectEditPolicy

  protected Command getDirectEditCommand(DirectEditRequest request)
  {

    RenameNodeCommand cmd = new RenameNodeCommand();
    cmd.setDiagram((Diagram) getHost().getParent().getModel());
    cmd.setNode((Node) getHost().getModel());
    cmd.setName((String) request.getCellEditor().getValue());
    return cmd;
  }

  protected void showCurrentEditValue(DirectEditRequest request)
  {
    Object nodeType = getHost().getModel();
    if (nodeType instanceof RectangleNode)
      {
        String value = (String) request.getCellEditor().getValue();
        ((RectangleNodeFigure) getHostFigure()).setName(value);
      }
    else if (nodeType instanceof PerformanceElement)
      {
        String value = (String) request.getCellEditor().getValue();
        ((PerformanceNodeFigure) getHostFigure()).setName(value);
      }
    else if (nodeType instanceof StartPointNode)
  {
    String value = (String) request.getCellEditor().getValue();
    ((StartPointFigure) getHostFigure()).setName(value);
  }
    else if (nodeType instanceof EndPointNode)
  {
    String value = (String) request.getCellEditor().getValue();
    ((EndPointFigure) getHostFigure()).setName(value);
  }
  }
}
